pub enum RolloutMode {
EpisodeBound {
n_episodes: usize,
},
StepBound {
n_steps: usize,
},
}Expand description
Bound used for one rollout collection request per environment.
Variants
EpisodeBound
Collect until each selected environment completes n_episodes.
StepBound
Collect a fixed number of steps from each selected environment.