pub struct DirectSampler<E: Env, H: DirectSamplerHook<E = E>> { /* private fields */ }Expand description
Rollout sampler whose workers write directly to output buffers.
Implementations
Sourceimpl<E: Env, H: DirectSamplerHook<E = E>> DirectSampler<E, H>
impl<E: Env, H: DirectSamplerHook<E = E>> DirectSampler<E, H>
pub fn new(core: DirectSamplerCore<E>, hook: H) -> Self
Sourcepub fn build<EB: EnvBuilder<Env = E>>(
env_builder: EnvBuilderType<EB>,
hook: H,
execution_mode: SamplerExecutionMode,
) -> Self
pub fn build<EB: EnvBuilder<Env = E>>( env_builder: EnvBuilderType<EB>, hook: H, execution_mode: SamplerExecutionMode, ) -> Self
Builds a raw sampler and its environment workers.
Sourcepub fn build_from_env_builder(
env_builder: Arc<dyn EnvBuilder<Env = E>>,
num_envs: usize,
hook: H,
execution_mode: SamplerExecutionMode,
) -> Result<Self>where
E: 'static,
pub fn build_from_env_builder(
env_builder: Arc<dyn EnvBuilder<Env = E>>,
num_envs: usize,
hook: H,
execution_mode: SamplerExecutionMode,
) -> Result<Self>where
E: 'static,
Builds a homogeneous sampler from a shared environment builder.
Errors
Returns an error if num_envs is zero.